@@ -108,13 +108,19 @@ class MarionetteTestResult(unittest._TextTestResult):
             self.stream.writeln("%s: %s" % (flavour, self.getDescription(test)))
             self.stream.writeln(self.separator2)
             errlines = err.strip().split('\n')
-            for line in errlines[0:-1]:
-                self.stream.writeln("%s" % line)
-            if "TEST-UNEXPECTED-FAIL" in errlines[-1]:
-                self.stream.writeln(errlines[-1])
-            else:
-                self.stream.writeln("TEST-UNEXPECTED-FAIL | %s | %s" %
-                                    (self.getInfo(test), errlines[-1]))
+            lastline = None
+            fail_present = None
+            for line in errlines:
+                if not line.startswith('\t'):
+                    lastline = line
+                if 'TEST-UNEXPECTED-FAIL' in line:
+                    fail_present = True
+            for line in errlines:
+                if line != lastline or fail_present:
+                    self.stream.writeln("%s" % line)
+                else:
+                    self.stream.writeln("TEST-UNEXPECTED-FAIL | %s | %s" %
+                                        (self.getInfo(test), line))
 
     def stopTest(self, *args, **kwargs):
         unittest._TextTestResult.stopTest(self, *args, **kwargs)
@@ -585,10 +591,10 @@ class MarionetteTestRunner(object):
         for results in results_list:
 
             for tup in results.errors:
-                _extract_xml(*tup, result='error')
+                _extract_xml(tup[0], text=tup[1], result='error')
 
             for tup in results.failures:
-                _extract_xml(*tup, result='failure')
+                _extract_xml(tup[0], text=tup[1], result='failure')
 
             if hasattr(results, 'unexpectedSuccesses'):
                 for test in results.unexpectedSuccesses:
@@ -597,11 +603,11 @@ class MarionetteTestRunner(object):
 
             if hasattr(results, 'skipped'):
                 for tup in results.skipped:
-                    _extract_xml(*tup, result='skipped')
+                    _extract_xml(tup[0], text=tup[1], result='skipped')
 
             if hasattr(results, 'expectedFailures'):
                 for tup in results.expectedFailures:
-                    _extract_xml(*tup, result='skipped')
+                    _extract_xml(tup[0], text=tup[1], result='skipped')
 
             for test in results.tests_passed:
                 _extract_xml(test)
